@@ -59,7 +59,7 @@ cli.add_command(export_blocks_and_transactions, "export_blocks_and_transactions"
 # cli.add_command(extract_token_transfers, "extract_token_transfers")
 cli.add_command(export_contracts, "export_contracts")
 # cli.add_command(export_tokens, "export_tokens")
-# cli.add_command(export_traces, "export_traces")
+cli.add_command(export_traces, "export_traces")
 # cli.add_command(export_geth_traces, "export_geth_traces")
 # cli.add_command(extract_geth_traces, "extract_geth_traces")
 cli.add_command(extract_contracts, "extract_contracts")
@@ -72,6 +72,6 @@ cli.add_command(stream, "stream")
 cli.add_command(get_block_range_for_date, "get_block_range_for_date")
 cli.add_command(get_block_range_for_timestamps, "get_block_range_for_timestamps")
 cli.add_command(get_keccak_hash, "get_keccak_hash")
-# cli.add_command(extract_csv_column, "extract_csv_column")
+cli.add_command(extract_csv_column, "extract_csv_column")
 cli.add_command(filter_items, "filter_items")
 # cli.add_command(extract_field, "extract_field")
